<?php

defined('ABSPATH') or die;

/*
 *
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 *
 * Add support tab
 *
 */
if ( ! defined('MTS_THEME_WHITE_LABEL') || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 *
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constants for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){

	//$sections = array();
	$sections[] = array(
				'title' => __('A Section added by hook', 'blogging' ),
				'desc' => '<p class="description">' . __('This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'blogging' ) . '</p>',
				//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
				//You don't have to though, leave it blank for default.
				'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
				//Lets leave this as a blank section, no options just some intro text set above.
				'fields' => array()
				);

	return $sections;

}//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 *
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){

	//$args['dev_mode'] = false;

	return $args;

}//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the options page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but they're to be overridden if needed.
 *
 *
 */

function setup_framework_options(){
	$args = array();

	//Set it to dev mode to view the class settings/info in the form - default is false
	$args['dev_mode'] = false;
	//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
	//$args['stylesheet_override'] = true;

	//Add HTML before the form
	//$args['intro_text'] = __('<p>This is the HTML which can be displayed before the form, it isnt required, but more info is always better. Anything goes in terms of markup here, any HTML.</p>', 'blogging' );

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Setup custom links in the footer for share icons
		$args['share_icons']['twitter'] = array(
			'link' => 'http://twitter.com/mythemeshopteam',
			'title' => __( 'Follow Us on Twitter', 'blogging' ),
			'img' => 'fa fa-twitter-square'
		);
		$args['share_icons']['facebook'] = array(
			'link' => 'http://www.facebook.com/mythemeshop',
			'title' => __( 'Like us on Facebook', 'blogging' ),
			'img' => 'fa fa-facebook-square'
		);
	}

	//Choose to disable the import/export feature
	//$args['show_import_export'] = false;

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
	$args['opt_name'] = MTS_THEME_NAME;

	//Custom menu icon
	//$args['menu_icon'] = '';

	//Custom menu title for options page - default is "Options"
	$args['menu_title'] = __('Theme Options', 'blogging' );

	//Custom Page Title for options page - default is "Options"
	$args['page_title'] = __('Theme Options', 'blogging' );

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
	$args['page_slug'] = 'theme_options';

	//Custom page capability - default is set to "manage_options"
	//$args['page_cap'] = 'manage_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
	//$args['page_type'] = 'submenu';

	//parent menu - default is set to "themes.php" (Appearance)
	//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	//$args['page_parent'] = 'themes.php';

	//custom page location - default 100 - must be unique or will override other items
	$args['page_position'] = 62;

	//Custom page icon class (used to override the page icon next to heading)
	//$args['page_icon'] = 'icon-themes';

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-1',
			'title' => __('Support', 'blogging' ),
			'content' => '<p>' . __('If you are facing any problem with our theme or theme option panel, head over to our', 'blogging' ) . ' <a href="http://community.mythemeshop.com/">Support Forums</a>.</p>'
		);
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-2',
			'title' => __('Earn Money', 'blogging' ),
			'content' => '<p>' . __('Earn 70% commision on every sale by refering your friends and readers. Join our', 'blogging' ) . ' <a href="http://mythemeshop.com/affiliate-program/">Affiliate Program</a>.</p>'
		);
	}

	//Set the Help Sidebar for the options page - no sidebar by default
	//$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'blogging' );

	$mts_patterns = array(
		'nobg' => array('img' => NHP_OPTIONS_URL.'img/patterns/nobg.png'),
		'pattern0' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern0.png'),
		'pattern1' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern1.png'),
		'pattern2' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern2.png'),
		'pattern3' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern3.png'),
		'pattern4' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern4.png'),
		'pattern5' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern5.png'),
		'pattern6' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern6.png'),
		'pattern7' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern7.png'),
		'pattern8' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern8.png'),
		'pattern9' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern9.png'),
		'pattern10' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern10.png'),
		'pattern11' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern11.png'),
		'pattern12' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern12.png'),
		'pattern13' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern13.png'),
		'pattern14' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern14.png'),
		'pattern15' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern15.png'),
		'pattern16' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern16.png'),
		'pattern17' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern17.png'),
		'pattern18' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern18.png'),
		'pattern19' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern19.png'),
		'pattern20' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern20.png'),
		'pattern21' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern21.png'),
		'pattern22' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern22.png'),
		'pattern23' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern23.png'),
		'pattern24' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern24.png'),
		'pattern25' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern25.png'),
		'pattern26' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern26.png'),
		'pattern27' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern27.png'),
		'pattern28' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern28.png'),
		'pattern29' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern29.png'),
		'pattern30' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern30.png'),
		'pattern31' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern31.png'),
		'pattern32' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern32.png'),
		'pattern33' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern33.png'),
		'pattern34' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern34.png'),
		'pattern35' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern35.png'),
		'pattern36' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern36.png'),
		'pattern37' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern37.png'),
		'hbg' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg.png'),
		'hbg2' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg2.png'),
		'hbg3' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg3.png'),
		'hbg4' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg4.png'),
		'hbg5' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg5.png'),
		'hbg6' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg6.png'),
		'hbg7' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg7.png'),
		'hbg8' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg8.png'),
		'hbg9' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg9.png'),
		'hbg10' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg10.png'),
		'hbg11' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg11.png'),
		'hbg12' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg12.png'),
		'hbg13' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg13.png'),
		'hbg14' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg14.png'),
		'hbg15' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg15.png'),
		'hbg16' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg16.png'),
		'hbg17' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg17.png'),
		'hbg18' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg18.png'),
		'hbg19' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg19.png'),
		'hbg20' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg20.png'),
		'hbg21' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg21.png'),
		'hbg22' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg22.png'),
		'hbg23' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg23.png'),
		'hbg24' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg24.png'),
		'hbg25' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg25.png')
	);

	$sections = array();

	$sections[] = array(
		'icon' => 'fa fa-cogs',
		'title' => __('General Settings', 'blogging' ),
		'desc' => '<p class="description">' . __('This tab contains common setting options which will be applied to the whole theme.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_logo',
				'type' => 'upload',
				'title' => __('Logo Image', 'blogging' ),
				'sub_desc' => __('Upload your logo using the Upload Button or insert image URL.', 'blogging' )
			),
			array(
				'id' => 'mts_favicon',
				'type' => 'upload',
				'title' => __('Favicon', 'blogging' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s favicon.', 'blogging' ), '<strong>32 x 32 px</strong>' ),
			),
			array(
				'id' => 'mts_touch_icon',
				'type' => 'upload',
				'title' => __('Touch icon', 'blogging' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', 'blogging' ), '<strong>152 x 152 px</strong>' ),
			),
			array(
				'id' => 'mts_metro_icon',
				'type' => 'upload',
				'title' => __('Metro icon', 'blogging' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s IE 10 Metro tile icon.', 'blogging' ), '<strong>144 x 144 px</strong>' ),
			),
			array(
				'id' => 'mts_twitter_username',
				'type' => 'text',
				'title' => __('Twitter Username', 'blogging' ),
				'sub_desc' => __('Enter your Username here.', 'blogging' ),
			),
			array(
				'id' => 'mts_feedburner',
				'type' => 'text',
				'title' => __('FeedBurner URL', 'blogging' ),
				'sub_desc' => sprintf( __('Enter your FeedBurner\'s URL here, ex: %s and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', 'blogging' ), '<strong>http://feeds.feedburner.com/mythemeshop</strong>' ),
				'validate' => 'url'
			),
			array(
				'id' => 'mts_header_code',
				'type' => 'textarea',
				'title' => __('Header Code', 'blogging' ),
				'sub_desc' => wp_kses( __('Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'blogging' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_analytics_code',
				'type' => 'textarea',
				'title' => __('Footer Code', 'blogging' ),
				'sub_desc' => wp_kses( __('Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'blogging' ), array( 'strong', 'a' => array( 'href' => array() ) ) )
			),
			array(
				'id' => 'mts_pagenavigation_type',
				'type' => 'radio',
				'title' => __('Pagination Type', 'blogging' ),
				'sub_desc' => __('Select pagination type.', 'blogging' ),
				'options' => array(
					'0'=> __('Default (Next / Previous)', 'blogging' ),
					'1' => __('Numbered (1 2 3 4...)', 'blogging' ),
					'2' => __( 'AJAX (Load More Button)', 'blogging' ),
					'3' => __( 'AJAX (Auto Infinite Scroll)', 'blogging' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_ajax_search',
				'type' => 'button_set',
				'title' => __('AJAX Quick search', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Enable or disable search results appearing instantly below the search form', 'blogging' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_responsive',
				'type' => 'button_set',
				'title' => __('Responsiveness', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', 'blogging' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_rtl',
				'type' => 'button_set',
				'title' => __('Right To Left Language Support', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Enable this option for right-to-left sites.', 'blogging' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_shop_products',
				'type' => 'text',
				'title' => __('No. of Products', 'blogging' ),
				'sub_desc' => __('Enter the total number of products which you want to show on shop page (WooCommerce plugin must be enabled).', 'blogging' ),
				'validate' => 'numeric',
				'std' => '9',
				'class' => 'small-text'
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-bolt',
		'title' => __('Performance', 'blogging' ),
		'desc' => '<p class="description">' . __('This tab contains performance-related options which can help speed up your website.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_prefetching',
				'type' => 'button_set',
				'title' => __('Prefetching', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', 'blogging' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_lazy_load',
				'type' => 'button_set_hide_below',
				'title' => __('Theme\'s Lazy Loading', 'blogging' ),
				'sub_desc' => __('Delay loading of images outside of viewport, until user scrolls to them.', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'std' => '0',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_lazy_load_thumbs',
				'type' => 'button_set',
				'title' => __('Lazy load featured images', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Enable or disable Lazy load of featured images across site.', 'blogging' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_lazy_load_content',
				'type' => 'button_set',
				'title' => __('Lazy load post content images', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Enable or disable Lazy load of images inside post/page content.', 'blogging' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_async_js',
				'type' => 'button_set',
				'title' => __('Async JavaScript', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => sprintf( __('Add %s attribute to script tags to improve page download speed.', 'blogging' ), '<code>async</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_remove_ver_params',
				'type' => 'button_set',
				'title' => __('Remove ver parameters', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => sprintf( __('Remove %s parameter from CSS and JS file calls. It may improve speed in some browsers which do not cache files having the parameter.', 'blogging' ), '<code>ver</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_optimize_wc',
				'type' => 'button_set',
				'title' => __('Optimize WooCommerce scripts', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Load WooCommerce scripts and styles only on WooCommerce pages (WooCommerce plugin must be enabled).', 'blogging' ),
				'std' => '1'
			),
			'cache_message' => array(
				'id' => 'mts_cache_message',
				'type' => 'info',
				'title' => __('Use Cache', 'blogging' ),
				'desc' => sprintf(
					__('A cache plugin can increase page download speed dramatically. We recommend using %1$s or %2$s.', 'blogging' ),
					'<a href="https://community.mythemeshop.com/tutorials/article/8-make-your-website-load-faster-using-w3-total-cache-plugin/" target="_blank" title="W3 Total Cache">W3 Total Cache</a>',
					'<a href="'.admin_url( 'plugin-install.php?tab=plugin-information&plugin=wp-super-cache&TB_iframe=true&width=772&height=574' ).'" class="thickbox" title="WP Super Cache">WP Super Cache</a>'
				),
			),
		)
	);

	// Hide cache message on multisite or if a chache plugin is active already
	if ( is_multisite() || strstr( join( ';', get_option( 'active_plugins' ) ), 'cache' ) ) {
		unset( $sections[1]['fields']['cache_message'] );
	}

	$sections[] = array(
		'icon' => 'fa fa-adjust',
		'title' => __('Styling Options', 'blogging' ),
		'desc' => '<p class="description">' . __('Control the visual appearance of your theme, such as colors, layout and patterns, from here.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_color_scheme',
				'type' => 'color',
				'title' => __('Color Scheme', 'blogging' ),
				'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', 'blogging' ),
				'std' => '#87bcde'
			),
			array(
				'id' => 'mts_color_scheme2',
				'type' => 'color',
				'title' => __('Color Scheme 2', 'blogging' ),
				'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', 'blogging' ),
				'std' => '#7dc561'
			),
			array(
				'id' => 'mts_layout',
				'type' => 'radio_img',
				'title' => __('Layout Style', 'blogging' ),
				'sub_desc' => wp_kses( __('Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', 'blogging' ), array( 'strong' => array() ) ),
				'options' => array(
					'cslayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/cs.png'),
					'sclayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/sc.png')
				),
				'std' => 'cslayout'
			),
			array(
				'id' => 'mts_background',
				'type' => 'background',
				'title' => __('Site Background', 'blogging' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'blogging' ),
				'options' => array(
					'color'         => '',            // false to disable, not needed otherwise
					'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! )
					'image_upload'  => '',            // false to disable, not needed otherwise
					'repeat'        => array(),       // false to disable, array of options to override default ( optional )
					'attachment'    => array(),       // false to disable, array of options to override default ( optional )
					'position'      => array(),       // false to disable, array of options to override default ( optional )
					'size'          => array(),       // false to disable, array of options to override default ( optional )
					'gradient'      => '',            // false to disable, not needed otherwise
					'parallax'      => array(),       // false to disable, array of options to override default ( optional )
				),
				'std' => array(
					'color'         => '#ffffff',
					'use'           => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'        => 'repeat',
					'attachment'    => 'scroll',
					'position'      => 'left top',
					'size'          => 'cover',
					'gradient'      => array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'      => '0',
				)
			),
			array(
				'id' => 'mts_custom_css',
				'type' => 'textarea',
				'title' => __('Custom CSS', 'blogging' ),
				'sub_desc' => __('You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'blogging' )
			),
			array(
				'id' => 'mts_lightbox',
				'type' => 'button_set',
				'title' => __('Lightbox', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', 'blogging' ),
				'std' => '0'
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-credit-card',
		'title' => __('Header', 'blogging' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of header section.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_header_layouts',
				'type' => 'radio_img',
				'title' => __('Header Layouts', 'blogging' ),
				'options' => array(
					'default' => array(
						'title' => __('Default Header Layout', 'blogging' ),
						'img'   => NHP_OPTIONS_URL.'img/layouts/header-layout1.png'
					),
					'2'       => array(
						'title' => __('Header Layout 2', 'blogging' ),
						'img'   => NHP_OPTIONS_URL.'img/layouts/header-layout2.png'
					),
					'3'       => array(
						'title' => __('Header Layout 3', 'blogging' ),
						'img'   => NHP_OPTIONS_URL.'img/layouts/header-layout3.png'
					),
				),
				'sub_desc' => wp_kses( __('Choose header layout from the list of <strong>Header Layouts</strong>', 'blogging' ), array( 'strong' => array() ) ),
				'std' => 'default',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'mts_header_bg_color',
				'type' => 'color',
				'title' => __('Header Background', 'blogging'),
				'sub_desc' => __('Choose the background color you want to use in header.', 'blogging'),
				'std' => '#2B3338'
			),
			array(
				'id' => 'layout2_top_header_bg',
				'type' => 'color',
				'title' => __('Top Header Background', 'blogging'),
				'sub_desc' => __('Choose the background color you want to use in top header for Layout 2 from here.', 'blogging'),
				'std' => '#20272b',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout2_bottom_header_bg',
				'type' => 'color',
				'title' => __('Bottom Header Background', 'blogging'),
				'sub_desc' => __('Choose the background color you want to use in bottom header for Layout 2 from here.', 'blogging'),
				'std' => '#2B3338',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout2_logo_alignment',
				'type' => 'button_set',
				'title' => __('Logo Alignment', 'blogging'),
				'options' => array('left' => __('Left', 'blogging' ), 'center' => __('Center', 'blogging' ), 'right' => __('Right', 'blogging' )),
				'sub_desc' => __('Change Logo alignment for Layout 2 from here.', 'blogging'),
				'std' => 'left',
				'class' => 'green',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout3_top_header_bg',
				'type' => 'color',
				'title' => __('Top Header Background', 'blogging'),
				'sub_desc' => __('Choose the background color you want to use in top header for Layout 3 from here.', 'blogging'),
				'std' => '#20272b',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout3_middle_header_bg',
				'type' => 'color',
				'title' => __('Middle Header Background', 'blogging'),
				'sub_desc' => __('Choose the background color you want to use in middle header for Layout 3 from here.', 'blogging'),
				'std' => '#2B3338',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout3_bottom_header_bg',
				'type' => 'color',
				'title' => __('Bottom Header Background', 'blogging'),
				'sub_desc' => __('Choose the background color you want to use in bottom header for Layout 3 from here.', 'blogging'),
				'std' => '#20272b',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout3_logo_alignment',
				'type' => 'button_set',
				'title' => __('Logo Alignment', 'blogging'),
				'options' => array('left' => __('Left', 'blogging' ), 'center' => __('Center', 'blogging' ), 'right' => __('Right', 'blogging' )),
				'sub_desc' => __('Change Logo alignment for Layout 3 from here.', 'blogging'),
				'std' => 'left',
				'class' => 'green',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'layout3_nav_alignment',
				'type' => 'button_set',
				'title' => __('Navigation Alignment', 'blogging'),
				'options' => array('left' => __('Left', 'blogging' ), 'center' => __('Center', 'blogging' ), 'right' => __('Right', 'blogging' )),
				'sub_desc' => __('Change Navigation alignment for Layout 3 from here.', 'blogging'),
				'std' => 'left',
				'class' => 'green',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'mts_sticky_nav',
				'type' => 'button_set',
				'title' => __('Floating Navigation Menu', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'blogging' ), '<strong>' . __( 'Primary Navigation Menu', 'blogging' ) . '</strong>' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_header_section2',
				'type' => 'button_set',
				'title' => __('Show Logo', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide <strong>Logo</strong> completely.', 'blogging' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_show_primary_nav',
				'type' => 'button_set',
				'title' => __('Show Primary Menu', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'blogging' ), '<strong>' . __( 'Primary Navigation Menu', 'blogging' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_search',
				'type' => 'button_set',
				'title' => __('Show Search Form in Header', 'blogging'),
				'options' => array('0' => __( 'Off', 'blogging'),'1' => __( 'On', 'blogging')),
				'sub_desc' => wp_kses( __('Use this button to enable <strong>Search Icon in top navigation</strong>.', 'blogging' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_social',
				'title' => __('Header Social Icons', 'blogging'),
				'sub_desc' => __( 'Add Social Media icons in header.', 'blogging' ),
				'type' => 'group',
				'groupname' => __('Header Icons', 'blogging'), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_header_icon_title',
						'type' => 'text',
						'title' => __('Title', 'blogging'),
					),
					array(
						'id' => 'mts_header_icon',
						'type' => 'icon_select',
						'title' => __('Icon', 'blogging'),
					),
					array(
						'id' => 'mts_header_icon_link',
						'type' => 'text',
						'title' => __('URL', 'blogging'),
					),
					array(
						'id' => 'mts_header_icon_color',
						'type' => 'color',
						'title' => __('Font Color', 'blogging'),
						'std' => '#3f4243',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_header_icon_bg_color',
						'type' => 'color',
						'title' => __('Background Color', 'blogging'),
						'std' => '#7f8487',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_header_hover_icon_color',
						'type' => 'color',
						'title' => __('Hover Color', 'blogging'),
						'std' => '#ffffff',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_header_hover_icon_bg_color',
						'type' => 'color',
						'title' => __('Hover Background Color', 'blogging'),
						'std' => '#87bcde',
						'reset_at_version' => '3.0.0'
					),
				),
				'std' => array(
					'facebook' => array(
						'group_title' => 'Facebook',
						'group_sort' => '1',
						'mts_header_icon_title' => 'Facebook',
						'mts_header_icon' => 'facebook',
						'mts_header_icon_link' => '#',
						'mts_header_icon_color' => '#3f4243',
						'mts_header_icon_bg_color' => '#7f8487',
						'mts_header_hover_icon_color' => '#ffffff',
						'mts_header_hover_icon_bg_color' => '#87bcde',
						'reset_at_version' => '3.0.0'
					),
					'twitter' => array(
						'group_title' => 'Twitter',
						'group_sort' => '2',
						'mts_header_icon_title' => 'Twitter',
						'mts_header_icon' => 'twitter',
						'mts_header_icon_link' => '#',
						'mts_header_icon_color' => '#3f4243',
						'mts_header_icon_bg_color' => '#7f8487',
						'mts_header_hover_icon_color' => '#ffffff',
						'mts_header_hover_icon_bg_color' => '#87bcde',
						'reset_at_version' => '3.0.0'
					),
				)
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-table',
		'title' => __('Footer', 'blogging' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of Footer section.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_first_footer',
				'type' => 'button_set_hide_below',
				'title' => __('Footer Widgets', 'blogging' ),
				'sub_desc' => __('Enable or disable footer widgets with this option.', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'std' => '0',
				'args' => array('hide' => 2)
			),
			array(
				'id' => 'mts_first_footer_num',
				'type' => 'button_set',
				'class' => 'green',
				'title' => __('Footer Widgets Layout', 'blogging' ),
				'sub_desc' => wp_kses( __('Choose the number of widget areas in the <strong>footer</strong>', 'blogging' ), array( 'strong' => '' ) ),
				'options' => array(
					'3' => __( '3 Widgets', 'blogging' ),
					'4' => __( '4 Widgets', 'blogging' ),
				),
				'std' => '3'
			),
			array(
				'id' => 'mts_footer_bg_color',
				'type' => 'background',
				'title' => __('Footer Background', 'blogging' ),
				'sub_desc' => __('Set footer background color, pattern or image from here.', 'blogging' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'      => array(),
				),
				'std' => array(
					'color'		 => '#28202e',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'      => '0',
				)
			),
			array(
				'id' => 'mts_show_footer_nav',
				'type' => 'button_set',
				'title' => __('Show Footer Navigation Menu', 'blogging'),
				'options' => array('0' => __( 'Off', 'blogging'),'1' => __( 'On', 'blogging')),
				'sub_desc' => wp_kses( __('Use this button to enable <strong>Footer Navigation Menu</strong>', 'blogging' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_footer_social',
				'title' => __('Footer Social Icons', 'blogging'),
				'sub_desc' => __( 'Add Social Media icons in Footer.', 'blogging' ),
				'type' => 'group',
				'groupname' => __('Footer Icons', 'blogging'), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_footer_icon_title',
						'type' => 'text',
						'title' => __('Title', 'blogging'),
					),
					array(
						'id' => 'mts_footer_icon',
						'type' => 'icon_select',
						'title' => __('Icon', 'blogging')
					),
					array(
						'id' => 'mts_footer_icon_link',
						'type' => 'text',
						'title' => __('URL', 'blogging'),
					),
					array(
						'id' => 'mts_footer_icon_color',
						'type' => 'color',
						'title' => __('Font Color', 'blogging'),
						'std' => '#3f4243',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_footer_icon_bg_color',
						'type' => 'color',
						'title' => __('Background Color', 'blogging'),
						'std' => '#7f8487',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_footer_hover_icon_color',
						'type' => 'color',
						'title' => __('Hover Color', 'blogging'),
						'std' => '#ffffff',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_footer_hover_icon_bg_color',
						'type' => 'color',
						'title' => __('Hover Background Color', 'blogging'),
						'std' => '#87bcde',
						'reset_at_version' => '3.0.0'
					),
				),
				'std' => array(
					'facebook' => array(
						'group_title' => 'Facebook',
						'group_sort' => '1',
						'mts_footer_icon_title' => 'Facebook',
						'mts_footer_icon' => 'facebook',
						'mts_footer_icon_link' => '#',
						'mts_footer_icon_color' => '#3f4243',
						'mts_footer_icon_bg_color' => '#7f8487',
						'mts_footer_hover_icon_color' => '#ffffff',
						'mts_footer_hover_icon_bg_color' => '#87bcde',
						'reset_at_version' => '3.0.0'
					),
					'twitter' => array(
						'group_title' => 'Twitter',
						'group_sort' => '2',
						'mts_footer_icon_title' => 'Twitter',
						'mts_footer_icon' => 'twitter',
						'mts_footer_icon_link' => '#',
						'mts_footer_icon_color' => '#3f4243',
						'mts_footer_icon_bg_color' => '#7f8487',
						'mts_footer_hover_icon_color' => '#ffffff',
						'mts_footer_hover_icon_bg_color' => '#87bcde',
						'reset_at_version' => '3.0.0'
					),
				),
			),
			array(
				'id' => 'mts_copyrights_background',
				'type' => 'background',
				'title' => __('Copyright&#39;s Background', 'blogging' ),
				'sub_desc' => __('Set Copyright&#39;s background color, pattern or image from here.', 'blogging' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#1d1721',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_copyrights',
				'type' => 'textarea',
				'title' => __('Copyrights Text', 'blogging' ),
				'sub_desc' => __( 'You can change or remove our link from footer and use your own custom text.', 'blogging' ) . ( MTS_THEME_WHITE_LABEL ? '' : wp_kses( __('(You can also use your affiliate link to <strong>earn 55% of sales</strong>. Ex: <a href="https://mythemeshop.com/go/aff/aff" target="_blank">https://mythemeshop.com/?ref=username</a>)', 'blogging' ), array( 'strong' => array(), 'a' => array( 'href' => array(), 'target' => array() ) ) ) ),
				'std' => MTS_THEME_WHITE_LABEL ? null : sprintf( __( 'Theme by %s', 'blogging' ), '<a href="http://mythemeshop.com/">MyThemeShop</a>' )
			),
		),
	);

	$sections[] = array(
		'icon' => 'fa fa-home',
		'title' => __('Homepage', 'blogging' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of the homepage.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_featured_slider',
				'type' => 'button_set_hide_below',
				'title' => __('Homepage Slider', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => wp_kses( __('<strong>Enable or Disable</strong> homepage slider with this button. The slider will show recent articles from the selected categories.', 'blogging' ), array( 'strong' => array() ) ),
				'std' => '0',
				'args' => array('hide' => 5)
			),
			array(
				'id' => 'mts_featured_slider_cat',
				'type' => 'cats_multi_select',
				'title' => __('Slider Category(s)', 'blogging' ),
				'sub_desc' => wp_kses( __('Select a category from the drop-down menu, latest articles from this category will be shown <strong>in the slider</strong>.', 'blogging' ), array( 'strong' => array() ) ),
			),
			array(
				'id' => 'mts_featured_slider_num',
				'type' => 'text',
				'class' => 'small-text',
				'title' => __('Number of posts', 'blogging' ),
				'sub_desc' => __('Enter the number of posts to show in the slider', 'blogging' ),
				'std' => '6',
				'args' => array('type' => 'number')
			),
			array(
				'id'       => 'mts_slider_headline_meta_info',
				'type'     => 'layout',
				'title'    => __('Meta Info to Show on Slider', 'blogging'),
				'sub_desc' => __('Organize how you want the post meta info to appear', 'blogging'),
				'options'  => array(
					'enabled'  => array(
						'author'   => __('Author Name','blogging'),
						'category' => __('Categories','blogging')
					),
					'disabled' => array(
						'date'     => __('Date','blogging'),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'author'   => __('Author Name','blogging'),
						'category' => __('Categories','blogging')
					),
					'disabled' => array(
						'date'     => __('Date','blogging'),
					)
				)
			),
			array(
				'id' => 'mts_featured_slider_controls',
				'type' => 'button_set',
				'title' => __('Slider Controls', 'blogging' ),
				'options' => array('next-prev' => __('Arrows', 'blogging' ), 'dots' => __('Dots', 'blogging' ), 'both' => __('Both', 'blogging' )),
				'sub_desc' => __('Set homepage featured slider controls from here.', 'blogging' ),
				'std' => 'next-prev',
				'class' => 'green',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'mts_featured_slider_autoplay',
				'type' => 'button_set',
				'title' => __('Slider AutoPlay', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Enable/Disable Homepage featured slider autoplay with this button.', 'blogging' ),
				'std' => '0',
				'args' => array('hide' => 1),
				'reset_at_version' => '3.0.0'
			),
			array(
				'id'        => 'mts_featured_categories',
				'type'      => 'group',
				'title'     => __('Featured Categories', 'blogging' ),
				'sub_desc'  => __('Select categories appearing on the homepage.', 'blogging' ),
				'groupname' => __('Section', 'blogging' ), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_featured_category',
						'type' => 'cats_select',
						'title' => __('Category', 'blogging' ),
						'sub_desc' => __('Select a category or the latest posts for this section', 'blogging' ),
						'std' => 'latest',
						'args' => array('include_latest' => 1, 'hide_empty' => 0),
					),
					array(
						'id' => 'mts_featured_category_layout',
						'type' => 'select',
						'title' => __('Posts Layout', 'blogging'),
						'sub_desc' => __('Select the posts layout for this section.', 'blogging') ,
						'options' => array(
							'default'     => __('Default Layout', 'blogging' ),
							'two-grid'    => __('Two Grid Layout', 'blogging' ),
							'traditional' => __('Traditional Layout', 'blogging' ),
						),
						'std' => 'default',
						'reset_at_version' => '3.0.0'
					),
					array(
						'id' => 'mts_featured_category_postsnum',
						'type' => 'text',
						'class' => 'small-text',
						'title' => __('Number of posts', 'blogging' ),
						'sub_desc' => __('Enter the number of posts to show in this section.', 'blogging' ),
						'std' => '3',
						'args' => array('type' => 'number')
					),
				),
				'std' => array(
					'1' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_featured_category' => 'latest',
						'mts_featured_category_postsnum' => get_option('posts_per_page')
					)
				)
			),
			array(
				'id' => 'mts_sidebar_layout',
				'type' => 'button_set',
				'title' => __('HomePage Sidebar Type', 'blogging'),
				'options' => array('0' => __( 'Limited Height', 'blogging'), '1' => __( 'Full Height', 'blogging')),
				'class' => 'green',
				'sub_desc' => wp_kses( __('Should sidebar be inserted in Posts Grid or it should be Full Height. The same will be applied to post archive pages. This will be applied only to <strong>Default Layout</strong>', 'blogging' ), array( 'strong' => array() ) ),
				'std' => '0'
			),
			array(
				'id'       => 'mts_home_headline_meta_info',
				'type'     => 'layout',
				'title'    => __('HomePage Post Meta Info', 'blogging' ),
				'sub_desc' => __('Organize how you want the post meta info to appear on the homepage', 'blogging' ),
				'options'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'blogging' ),
						'date'     => __('Date', 'blogging' )
					),
					'disabled' => array()
				),
				'std'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'blogging' ),
						'date'     => __('Date', 'blogging' )
					),
					'disabled' => array(),
				)
			),
			array(
				'id' => 'mts_category_home',
				'type' => 'button_set',
				'title' => __('Show Category on Featured Image', 'blogging'),
				'options' => array('0' => __( 'Off', 'blogging'),'1' => __( 'On', 'blogging')),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide <strong>Category</strong> on Featured Image', 'blogging' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-file-text',
		'title' => __('Single Posts', 'blogging' ),
		'desc' => '<p class="description">' . __('From here, you can control the appearance and functionality of your single posts page.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_breadcrumb',
				'type' => 'button_set',
				'title' => __('Breadcrumbs', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'blogging' ),
				'std' => '1'
			),
			array(
				'id'       => 'mts_single_post_layout',
				'type'     => 'layout2',
				'title'    => __('Single Post Layout', 'blogging' ),
				'sub_desc' => __('Customize the look of single posts', 'blogging' ),
				'options'  => array(
					'enabled'  => array(
						'content'   => array(
							'label' 	=> __('Post Content', 'blogging' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_single_featured',
									'type' => 'button_set',
									'title' => __('Show Featured Image', 'blogging'),
									'options' => array('0' => __( 'Off', 'blogging'),'1' => __( 'On', 'blogging')),
									'sub_desc' => __('Use this button to show featured image on single posts.', 'blogging'),
									'std' => '1'
								),
							),
						),
						'related'   => array(
							'label' 	=> __('Related Posts', 'blogging' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_related_posts_taxonomy',
									'type' => 'button_set',
									'title' => __('Related Posts Taxonomy', 'blogging' ) ,
									'options' => array(
										'tags' => __( 'Tags', 'blogging' ),
										'categories' => __( 'Categories', 'blogging' )
									) ,
									'class' => 'green',
									'sub_desc' => __('Related Posts based on tags or categories.', 'blogging' ) ,
									'std' => 'categories'
								),
								array(
									'id' => 'mts_related_postsnum',
									'type' => 'text',
									'class' => 'small-text',
									'title' => __('Number of related posts', 'blogging' ) ,
									'sub_desc' => __('Enter the number of posts to show in the related posts section.', 'blogging' ) ,
									'std' => '2',
									'args' => array('type' => 'number'),
								),
							),
						),
						'author'   => array(
							'label' 	=> __('Author Box', 'blogging' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_author_readmore',
									'type' => 'button_set',
									'title' => __('Read More', 'blogging'),
									'options' => array('0' => __( 'Off', 'blogging'), '1' => __( 'On', 'blogging')),
									'sub_desc' => __('Show Read More button from here.', 'blogging'),
									'std' => '1',
									'reset_at_version' => '3.0.0'
								),
								array(
									'id' => 'mts_author_name',
									'type' => 'button_set',
									'title' => __('Author label', 'blogging'),
									'options' => array('0' => __( 'Off', 'blogging'), '1' => __( 'On', 'blogging')),
									'sub_desc' => __('Show Author Name from here.', 'blogging'),
									'std' => '1',
									'reset_at_version' => '3.0.0'
								),
								array(
									'id' => 'mts_author_num_posts',
									'type' => 'button_set',
									'title' => __('Number of Posts', 'blogging'),
									'options' => array('0' => __( 'Off', 'blogging'),'1' => __( 'On', 'blogging')),
									'sub_desc' => __('Show number of author posts.', 'blogging'),
									'std' => '1',
									'reset_at_version' => '3.0.0'
								),
							),
						),
					),
					'disabled' => array(
						'tags'   => array(
							'label' 	=> __('Tags', 'blogging' ),
							'subfields'	=> array(),
						),
					)
				)
			),
			array(
				'id'       => 'mts_single_headline_meta_info',
				'type'     => 'layout',
				'title'    => __('Meta Info to Show', 'blogging' ),
				'sub_desc' => __('Organize how you want the post meta info to appear', 'blogging' ),
				'options'  => array(
					'enabled'  => array(
						'category' => __('Categories', 'blogging' ),
						'author'   => __('Author Name', 'blogging' ),
						'date'     => __('Date', 'blogging' ),
						'comment'  => __('Comment Count', 'blogging' )
					),
					'disabled' => array()
				),
				'std'  => array(
					'enabled'  => array(
						'category' => __('Categories', 'blogging' ),
						'author'   => __('Author Name', 'blogging' ),
						'date'     => __('Date', 'blogging' ),
						'comment'  => __('Comment Count', 'blogging' )
					),
					'disabled' => array()
				)
			),
			array(
				'id'       => 'mts_related_headline_meta_info',
				'type'     => 'layout',
				'title'    => __('Meta Info to Show on Related Posts', 'blogging'),
				'sub_desc' => __('Organize how you want the post meta info to appear on Related posts', 'blogging'),
				'options'  => array(
						'enabled'  => array(
							'author'   => __('Author Name','blogging'),
							'date'     => __('Date','blogging')
						),
						'disabled' => array(
							'comment'  => __('Comment Count','blogging')
						)
				),
				'std'  => array(
					'enabled'  => array(
						'author'   => __('Author Name','blogging'),
						'date'     => __('Date','blogging')
					),
					'disabled' => array(
						'comment'  => __('Comment Count','blogging')
					)
				)
			),
			array(
				'id' => 'mts_category_related',
				'type' => 'button_set',
				'title' => __('Show Category on Related Posts', 'blogging'),
				'options' => array('0' => __( 'Off', 'blogging'),'1' => __( 'On', 'blogging')),
				'sub_desc' => __('Show Category on Related Post thumbnails.', 'blogging'),
				'std' => '1'
			),
			array(
				'id'       => 'mts_comments',
				'type'     => 'layout2',
				'title'    => __('Comments', 'blogging'),
				'sub_desc' => __('Show standard comments, Facebook comments, or both, in tabs layout.', 'blogging'),
				'options'  => array(
					'enabled'  => array(
						'comments'   => array(
							'label' 	=> __('Comments','blogging'),
							'subfields'	=> array()
						),
					),
					'disabled' => array(
						'fb_comments'   => array(
							'label' 	=> __('Facebook Comments','blogging'),
							'subfields'	=> array(
								array(
									'id' => 'mts_fb_app_id',
									'type' => 'text',
									'title' => __('Facebook App ID', 'blogging'),
									'sub_desc' => __('Enter your Facebook app ID here. You can create Facebook App id <a href="https://developers.facebook.com/apps" target="_blank">here</a>', 'blogging'),
									'class' => 'small'
								),
							)
						),
					)
				),
				'std' => array(
					'enabled'  => array(
						'comments'   => array(
							'label' 	=> __('Comments','blogging'),
							'subfields'	=> array()
						),
					),
					'disabled' => array(
						'fb_comments'   => array(
							'label' 	=> __('Facebook Comments','blogging'),
							'subfields'	=> array(
								array(
									'id' => 'mts_fb_app_id',
									'type' => 'text',
									'title' => __('Facebook App ID', 'blogging'),
									'sub_desc' => __('Enter your Facebook app ID here. You can create Facebook App id <a href="https://developers.facebook.com/apps" target="_blank">here</a>', 'blogging'),
									'class' => 'small'
								),
							)
						),
					)
				),
			),
			array(
				'id' => 'mts_author_comment',
				'type' => 'button_set',
				'title' => __('Highlight Author Comment', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Use this button to highlight author comments.', 'blogging' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_date',
				'type' => 'button_set',
				'title' => __('Date in Comments', 'blogging' ),
				'options' => array( '0' => __( 'Off', 'blogging' ), '1' => __( 'On', 'blogging' ) ),
				'sub_desc' => __('Use this button to show the date for comments.', 'blogging' ),
				'std' => '1'
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-group',
		'title' => __('Social Buttons', 'blogging' ),
		'desc' => '<p class="description">' . __('Enable or disable social sharing buttons on single posts using these buttons.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_social_button_layout',
				'type' => 'radio_img',
				'title' => __('Social Sharing Buttons Layout', 'blogging' ),
				'sub_desc' => wp_kses( __('Choose default <strong>social sharing buttons</strong> layout or modern <strong>social sharing buttons</strong> layout for your site. ', 'blogging' ), array( 'strong' => array() ) ),
				'options' => array(
					'default' => array('img' => NHP_OPTIONS_URL.'img/layouts/default-social.jpg'),
					'modern' => array('img' => NHP_OPTIONS_URL.'img/layouts/modern-social.jpg')
				),
				'std' => 'default',
				'reset_at_version' => '3.0.0'
			),
			array(
				'id' => 'mts_social_button_position',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons Position', 'blogging' ),
				'options' => array('top' => __('Above Content', 'blogging' ), 'bottom' => __('Below Content', 'blogging' ), 'floating' => __('Floating', 'blogging' )),
				'sub_desc' => __('Choose position for Social Sharing Buttons.', 'blogging' ),
				'std' => 'floating',
				'class' => 'green'
			),
			array(
				'id' => 'mts_social_buttons_on_pages',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons on Pages', 'blogging' ),
				'options' => array('0' => __('Off', 'blogging' ), '1' => __('On', 'blogging' )),
				'sub_desc' => __('Enable the sharing buttons for pages too, not just posts.', 'blogging' ),
				'std' => '0',
			),
			array(
				'id'       => 'mts_social_buttons',
				'type'     => 'layout',
				'title'    => __('Social Media Buttons', 'blogging' ),
				'sub_desc' => __('Organize how you want the social sharing buttons to appear on single posts', 'blogging' ),
				'options'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'blogging' ),
						'facebook'  => __('Facebook Like', 'blogging' ),
						'twitter'   => __('Twitter', 'blogging' ),
						'pinterest' => __('Pinterest', 'blogging' ),
					),
					'disabled' => array(
						'linkedin'  => __('LinkedIn', 'blogging' ),
						'stumble'   => __('StumbleUpon', 'blogging' ),
						'reddit'    => __('Reddit', 'blogging' ),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'blogging' ),
						'facebook'  => __('Facebook Like', 'blogging' ),
						'twitter'   => __('Twitter', 'blogging' ),
						'pinterest' => __('Pinterest', 'blogging' ),
					),
					'disabled' => array(
						'linkedin'  => __('LinkedIn', 'blogging' ),
						'stumble'   => __('StumbleUpon', 'blogging' ),
						'reddit'    => __('Reddit', 'blogging' ),
					)
				),
				'reset_at_version' => '3.0.0'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bar-chart-o',
		'title' => __('Ad Management', 'blogging' ),
		'desc' => '<p class="description">' . __('Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'blogging' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_posttop_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Title', 'blogging' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'blogging' )
			),
			array(
				'id' => 'mts_posttop_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'blogging' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'blogging' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
					'args' => array('type' => 'number')
			),
			array(
				'id' => 'mts_postend_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Content', 'blogging' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'blogging' )
			),
			array(
				'id' => 'mts_postend_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'blogging' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'blogging' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
					'args' => array('type' => 'number')
			),
		)
	);

	$sections[] = array(
		'icon' => 'fa fa-columns',
		'title' => __('Sidebars', 'blogging' ),
		'desc' => '<p class="description">' . __('Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.', 'blogging' ) . '<br></p>',
		'fields' => array(
			array(
				'id'        => 'mts_custom_sidebars',
				'type'      => 'group', //doesn't need to be called for callback fields
				'title'     => __('Custom Sidebars', 'blogging' ),
				'sub_desc'  => wp_kses( __('Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', 'blogging' ), array( 'strong' => array(), 'br' => array() ) ),
				'groupname' => __('Sidebar', 'blogging' ), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_custom_sidebar_name',
						'type' => 'text',
						'title' => __('Name', 'blogging' ),
						'sub_desc' => __('Example: Homepage Sidebar', 'blogging' )
					),
					array(
						'id' => 'mts_custom_sidebar_id',
						'type' => 'text',
						'title' => __('ID', 'blogging' ),
						'sub_desc' => __('Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', 'blogging' ),
						'std' => 'sidebar-'
					),
				),
			),
			array(
				'id' => 'mts_sidebar_for_home',
				'type' => 'sidebars_select',
				'title' => __('Homepage', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the homepage.', 'blogging' ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
					'std' => 'home-sidebar'
			),
			array(
				'id' => 'mts_sidebar_for_post',
				'type' => 'sidebars_select',
				'title' => __('Single Post', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', 'blogging' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_page',
				'type' => 'sidebars_select',
				'title' => __('Single Page', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', 'blogging' ),
					'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_archive',
				'type' => 'sidebars_select',
				'title' => __('Archive', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', 'blogging' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_category',
				'type' => 'sidebars_select',
				'title' => __('Category Archive', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the category archives.', 'blogging' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_tag',
				'type' => 'sidebars_select',
				'title' => __('Tag Archive', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the tag archives.', 'blogging' ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_date',
				'type' => 'sidebars_select',
				'title' => __('Date Archive', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the date archives.', 'blogging' ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_author',
				'type' => 'sidebars_select',
				'title' => __('Author Archive', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the author archives.', 'blogging' ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_search',
				'type' => 'sidebars_select',
				'title' => __('Search', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the search results.', 'blogging' ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_notfound',
				'type' => 'sidebars_select',
				'title' => __('404 Error', 'blogging' ),
				'sub_desc' => __('Select a sidebar for the 404 Not found pages.', 'blogging' ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_shop',
				'type' => 'sidebars_select',
				'title' => __('Shop Pages', 'blogging' ),
				'sub_desc' => wp_kses( __('Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', 'blogging' ), array( 'strong' => array() ) ),
					'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
					'std' => 'shop-sidebar'
			),
			array(
				'id' => 'mts_sidebar_for_product',
				'type' => 'sidebars_select',
				'title' => __('Single Product', 'blogging' ),
				'sub_desc' => wp_kses( __('Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', 'blogging' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar', 'home-sidebar')),
				'std' => 'product-sidebar'
			),
		),
	);
	//$sections[] = array(
	//				'icon' => NHP_OPTIONS_URL.'img/glyphicons/fontsetting.png',
	//				'title' => __('Fonts', 'blogging' ),
	//				'desc' => __('<p class="description"><div class="controls">You can find theme font options under the Appearance Section named <a href="themes.php?page=typography"><b>Theme Typography</b></a>, which will allow you to configure the typography used on your site.<br></div></p>', 'blogging' ),
	//				);

	$sections[] = array(
		'icon' => 'fa fa-list-alt',
		'title' => __('Navigation', 'blogging' ),
		'desc' => '<p class="description"><div class="controls">' . sprintf( __('Navigation settings can now be modified from the %s.', 'blogging' ), '<a href="nav-menus.php"><b>' . __( 'Menus Section', 'blogging' ) . '</b></a>' ) . '<br></div></p>'
	);


	$tabs = array();

	$args['presets'] = array();
	$args['show_translate'] = false;
	include('theme-presets.php');

	global $NHP_Options;
	$NHP_Options = new NHP_Options($sections, $args, $tabs);

}//function
add_action('init', 'setup_framework_options', 0);

/*
 *
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 *
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){

	$error = false;
	$value =  'just testing';
	/*
	do your validation

	if(something){
		$value = $value;
	}elseif(somthing else){
		$error = true;
		$value = $existing_value;
		$field['msg'] = 'your custom error message';
	}
	*/
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;

}//function

/*--------------------------------------------------------------------
 *
 * Default Font Settings
 *
 --------------------------------------------------------------------*/
if(function_exists('mts_register_typography')) {
	mts_register_typography(array(
		'logo_font' => array(
			'preview_text' => __( 'Logo Font', 'blogging' ),
			'preview_color' => 'dark',
			'font_family' => 'Source Sans Pro',
			'font_variant' => '600',
			'font_size' => '24px',
			'font_color' => '#dfdfdf',
			'additional_css' => 'text-transform: uppercase;',
			'css_selectors' => '#logo a'
		),
		'navigation_font' => array(
			'preview_text' => __( 'Navigation Font', 'blogging' ),
			'preview_color' => 'dark',
			'font_family' => 'Source Sans Pro',
			'font_variant' => '600',
			'font_size' => '15px',
			'font_color' => '#959a9e',
			'css_selectors' => '.menu li, .menu li a'
		),
		'home_title_font' => array(
			'preview_text' => __( 'Home Article Title', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_size' => '18px',
		'font_variant' => '700',
			'font_color' => '#2B3338',
			'css_selectors' => '.latestPost .title'
		),
		'single_title_font' => array(
			'preview_text' => __( 'Single Article Title', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_size' => '34px',
		'font_variant' => '700',
			'font_color' => '#2B3338',
			'css_selectors' => '.single-title'
		),
		'content_font' => array(
			'preview_text' => __( 'Content Font', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Source Sans Pro',
			'font_size' => '18px',
		'font_variant' => 'normal',
			'font_color' => '#57595f',
			'css_selectors' => 'body'
		),
	'sidebar_font' => array(
			'preview_text' => __( 'Sidebar Font', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#57595f',
			'css_selectors' => '#sidebar .widget'
		),
		'sidebar_link_font' => array(
			'preview_text' => 'Sidebar Links',
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '16px',
			'font_color' => '#2B3338',
			'css_selectors' => '.sidebar.c-4-12 a'
		),
		'slider_title' => array(
			'preview_text' => 'Slider Title',
			'preview_color' => 'dark',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '24px',
			'font_color' => '#ffffff',
			'css_selectors' => '.slide-title'
		),
		'h1_headline' => array(
			'preview_text' => __( 'Content H1', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '34px',
			'font_color' => '#2B3338',
			'css_selectors' => 'h1'
		),
	'h2_headline' => array(
			'preview_text' => __( 'Content H2', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '30px',
			'font_color' => '#2B3338',
			'css_selectors' => 'h2'
		),
	'h3_headline' => array(
			'preview_text' => __( 'Content H3', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '28px',
			'font_color' => '#2B3338',
			'css_selectors' => 'h3'
		),
	'h4_headline' => array(
			'preview_text' => __( 'Content H4', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '24px',
			'font_color' => '#2B3338',
			'css_selectors' => 'h4'
		),
	'h5_headline' => array(
			'preview_text' => __( 'Content H5', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '22px',
			'font_color' => '#2B3338',
			'css_selectors' => 'h5'
		),
	'h6_headline' => array(
			'preview_text' => __( 'Content H6', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Oxygen',
			'font_variant' => '700',
			'font_size' => '20px',
			'font_color' => '#2B3338',
			'css_selectors' => 'h6, .widget h3'
		),
		'footer_font' => array(
			'preview_text' => __( 'Footer Font', 'blogging' ),
			'preview_color' => 'light',
			'font_family' => 'Source Sans Pro',
			'font_variant' => '600',
			'font_size' => '13px',
			'font_color' => '#6e787f',
			'css_selectors' => '.copyrights, footer .menu li, footer .menu li a'
		),
		'footer_title_font' => array(
		'preview_text' => __( 'Footer Title Font', 'blogging' ),
		'preview_color' => 'dark',
		'font_family' => 'Rubik',
		'font_variant' => 'normal',
		'font_size' => '18px',
		'font_color' => '#e0dfe0',
		'css_selectors' => '.footer-widgets h3, .footer-widgets h3 a'
	),
	'footer_widget_font' => array(
		'preview_text' => __( 'Footer Widget Font', 'blogging' ),
		'preview_color' => 'dark',
		'font_family' => 'Rubik',
		'font_variant' => 'normal',
		'font_size' => '14px',
		'font_color' => '#aba9ac',
		'css_selectors' => '.footer-widgets, .footer-widgets a, .footer-widgets .widget_nav_menu a, .footer-widgets .wpt_widget_content a, .footer-widgets .wp_review_tab_widget_content a, #site-footer .entry-title a, #site-footer .merchant-rewards'
	),
	));
}

?>
